@@ -1,6 +1,6 @@
 """
 xb.Schema
-======
+==========
 
 Where traditional dataframe schema classes define what should go *inside*
 a dataframe's columns, `Schema` defines what those columns should be, 'when'
@@ -11,49 +11,56 @@ that state, change it, and move to new states seamlessly.
 It's a simple class, designed for ease of use and exceptional readability.
 
 It's a subclass of dictionary.
-    Keys: python-friendly variable names
-    Values: namedtuple: ("Input col name", "Output col name (optional)")
+
+* Keys: python-friendly variable names
+* Values: namedtuple: ("Input col name", "Output col name (optional)")
 
 Consider the following:
 
->>> sch_person = Schema(
-...     first_name=("FName", "First Name"),
-...     last_name=("LName", "Last Name"),
-...     favorite_food=("Fav Food", "Favorite Food"),
-... )
-...
->>> sch_company = Schema(
-...     comp_name=("Companyname", "Company Name"),
-...     market_cap="Market Capitalization",
-...     favorite_food="Preferred Employee Favorite Food",
-... )
-...
->>> sch_output = Schema(
-...     sch_person[[
-...         'last_name',
-...         'age',
-...     ]],
-...     sch_company[[
-...         'comp_name',
-...     ]],
-...     is_executive="Person is Executive"
-... )
+.. code-block::
+
+    sch_person = Schema(
+        first_name=("FName", "First Name"),
+        last_name=("LName", "Last Name"),
+        favorite_food=("Fav Food", "Favorite Food"),
+    )
+
+    sch_company = Schema(
+        comp_name=("Companyname", "Company Name"),
+        market_cap="Market Capitalization",
+        favorite_food="Preferred Employee Favorite Food",
+    )
+
+    sch_output = Schema(
+        sch_person[[
+            'last_name',
+            'age',
+        ]],
+        sch_company[[
+            'comp_name',
+        ]],
+        is_executive="Person is Executive"
+    )
+
 
 This should be readability-paradise. Given only the code above,
 the reader should know exactly what's supposed to happen in the script:
-    1. There are two input sources, person and company.
-    2. The script will have to join person and company, and include fields from each.
-    3. The script needs to add a new custom column, `is_executive`
+
+* There are two input sources, person and company.
+* The script will have to join person and company, and include fields from each.
+* The script needs to add a new custom column, `is_executive`
 
 
 Instance methods of this class try to provide as much utility as possible for
 common operations. Here are just a few:
-- `select_inputs()`: Take raw input data, validate our required columns can be
+
+* ``select_inputs()``: Take raw input data, validate our required columns can be
   found, select them, rename them python-friendly, and order them
-- `select_outputs()`: Do the opposite, and again, validate that all the columns
+* ``select_outputs()``: Do the opposite, and again, validate that all the columns
   required by our output schema are present.
-- `apply()`: Mid-workflow, safely re-order our columns and remove undesired ones.
+* ``apply()``: Mid-workflow, safely re-order our columns and remove undesired ones.
 """
+
 from __future__ import annotations
 
 from pandas import DataFrame
@@ -66,13 +73,57 @@ from typing import overload
 # The values held by each key of a Schema.
 # Tuple's immutability helps enforce consistency in user's code
 Column = namedtuple("Column", "input, output")
+Column.__doc__ = """
+The values stored by a :class:`xb.Schema <excelbird.schema.Schema>`
+
+A :class:`namedtuple` with two values, `input` and `output`, that
+can be accessed by dot notation, and is immutable.
+"""
 
 
 class Schema(dict):
+    """
+    Defines the state of a dataframe.
+
+    Parameters
+    ----------
+    *schemas : Schema
+        Existing schemas to use, to build a composite Schema that shows the reader
+        where the columns are coming from.
+    **kwargs : tuple[str, str] | tuple[str] | str
+        A mapping of python-friendly variable names to their corresponding input column
+        names and output column names. If value is a string, or 1-element tuple, it will
+        be applied as both the input and output name.
+
+    Examples
+    --------
+
+    Define a new schema
+
+    .. code-block::
+
+        sch_person = Schema(
+            first_name=("FName", "First Name"),
+            last_name=("LName", "Last Name"),
+            age="Age",
+        )
+
+    Define a composite schema that uses columns from a previous one
+
+    .. code-block::
+
+        sch_employee = Schema(
+            sch_person[[
+                'last_name',
+                'age',
+            ]],
+            rank="Rank"
+        )
+
+    """
     def __init__(
         self, *schemas, **kwargs: tuple[str, str] | tuple[str] | list[str] | str
     ) -> None:
-        """Accepts keyword args only to enforce that var names are valid python"""
         if not all(isinstance(s, Schema) for s in schemas):
             raise TypeError("Positional args can only be existing Schemas")
         # Convert all passed values to tuples
@@ -110,9 +161,26 @@ class Schema(dict):
 
     def __getitem__(self, key) -> Column | Schema:
         """
-        Acts normal, unless you past a list.
-        If a list is passed, filter and re-order the schema just like a
-        dataframe. Returns new object
+        Called when accessing items with ``sch[<key>]`` syntax.
+
+        Acts exactly like :class:`dict`'s ``__getitem__``, unless a
+        :class:`list` is passed. Pass a list of keys to return a *new*
+        object with the selected elements, in the desired order, similar
+        to how a :class:`pd.DataFrame <pandas.DataFrame>` works.
+
+        Parameters
+        ----------
+        key : str or int or list[str] or slice
+            Used to access items
+
+        Returns
+        -------
+        :class:`xb.Column <excelbird.schema.Column>`
+            If a non-list key is used
+
+        :class:`xb.Schema <excelbird.schema.Schema>`
+            If a list key is used
+            
         """
         if not isinstance(key, list):
             return super().__getitem__(key)
@@ -141,7 +209,16 @@ class Schema(dict):
 
     def drop(self, columns: list[str] | str) -> Schema:
         """
-        Drop the specified keys
+        Returns a copy of Self with the specified keys dropped
+
+        Parameters
+        ----------
+        columns : list[str] or str
+            The items to drop
+
+        Returns
+        -------
+        :class:`Self`
         """
         if not isinstance(columns, (list, tuple)):
             columns = [columns]
@@ -152,11 +229,23 @@ class Schema(dict):
 
     def apply(self, df: DataFrame, strict: bool = False) -> DataFrame:
         """
-        - Filter ``df`` to remove columns that aren't in self
-        - Re-order columns according to self's order
+        Removes columns from a dataframe that aren't in the schema,
+        and re-orders columns according to schema's order. If ``strict=True``,
+        An error will be raised if ``df`` doesn't contain at least all the
+        desired columns
+
+        Parameters
+        ----------
+        df : pd.DataFrame
+            Dataframe to apply the changes
+        strict : bool, default False
+            Whether to enforce that ``df`` must contain all columns needed by the schema
+
+        Returns
+        -------
+        :class:`pd.DataFrame <pandas.DataFrame>`
+            The updated dataframe
 
-        If ``strict=True``, raise an error if ``df`` doesn't at least contain
-        all columns specified in self.
         """
         if strict is False:
             return df[[k for k in self.keys() if k in df.columns]].copy()
@@ -171,13 +260,29 @@ class Schema(dict):
 
     def rename(
         self,
-        keys: dict | None = None,
-        inputs: dict | None = None,
-        outputs: dict | None = None,
+        keys: dict[str, str] | None = None,
+        inputs: dict[str, str] | None = None,
+        outputs: dict[str, str] | None = None,
     ) -> Schema:
         """
-        Rename any part of self's items (key, input, output), by passing a dict
-        who's keys are a current key in self, and values are the updated element.
+        Rename any part of the schema's data (keys, inputs, outputs) using a dictionary.
+        Pick *one* of ``keys``, ``inputs``, ``outputs``.
+
+        Regardless of which option is chosen, the **keys** in the provided dictionary
+        must represent **current** keys in the schema.
+
+        Parameters
+        ----------
+        keys : dict[str, str], optional
+            Mapping to rename the keys in the current schema
+        inputs : dict[str, str], optional
+            Mapping to rename the inputs in the current schema
+        outputs : dict[str, str], optional
+            Mapping to rename the outputs in the current schema
+
+        Returns
+        -------
+        :class:`Self`
         """
         new = self.copy()
         if keys is not None:
@@ -198,42 +303,100 @@ class Schema(dict):
 
         return new
 
-    def update(self, new: dict | None = None, **kwargs) -> None:
+    def update(self, other: Schema | dict | None = None, **kwargs) -> None:
         """
-        Like ``dict.update()``, but if a regular ``dict`` or kwargs are passed,
-        they're first used to create a new ``Schema`` before updating, so the
-        correct format is maintained
+        Just like the normal :meth:`dict.update`, but if a regular :class:`dict`,
+        or keyword arguments are passed, the arguments are first converted to
+        a :class:`Schema <excelbird.schema.Schema>` before updating.
+
+        Parameters
+        ----------
+        other : Schema or dict, optional
+            Mapping to update the current schema with
+        **kwargs : str
+            Used to create a Schema first, then update the current one with it.
+            
+        Returns
+        -------
+        :class:`Self`
         """
-        if isinstance(new, type(self)):
-            return super().update(new)
-        if new is not None:
-            return super().update(type(self)(**new))
+        if isinstance(other, type(self)):
+            return super().update(other)
+        if other is not None:
+            return super().update(type(self)(**other))
         return super().update(type(self)(**kwargs))
 
     def rename_inputs_to_vars(self, df: DataFrame) -> DataFrame:
         """
-        Take a dataframe in its input format and rename its columns to the
-        python-friendly keys in self.
+        Calls :meth:`df.rename <pandas.DataFrame.rename>` on the given
+        dataframe and provides a mapping from the inputs in the current
+        schema to the keys in the current schema
+
+        Parameters
+        ----------
+        df : pd.DataFrame
+            Dataframe to update
+
+        Returns
+        -------
+        pd.DataFrame
+            The updated dataframe
         """
         return df.rename(columns={val.input: key for key, val in self.items()})
 
     def rename_vars_to_outputs(self, df: DataFrame) -> DataFrame:
         """
-        Rename columns to self's output names
+        Calls :meth:`df.rename <pandas.DataFrame.rename>` on the given
+        dataframe and provides a mapping from the keys in the current
+        schema to the outputs in the current schema
+
+        Parameters
+        ----------
+        df : pd.DataFrame
+            Dataframe to update
+
+        Returns
+        -------
+        pd.DataFrame
+            The updated dataframe
         """
         return df.rename(columns={key: val.output for key, val in self.items()})
 
     def inputs(self) -> list[str]:
+        """
+        The input values for each key in the schema
+
+        Returns
+        -------
+        list[str]
+        """
         return [val.input for val in self.values()]
 
     def outputs(self) -> list[str]:
+        """
+        The output values for each key in the schema
+
+        Returns
+        -------
+        list[str]
+        """
         return [val.output for val in self.values()]
 
     def select_inputs(self, df: DataFrame) -> DataFrame:
         """
-        Renames desired columns to var names, and selects them.
+        Renames desired columns to var names, and selects them in the
+        order of the schema.
         If a column isn't found, an error is raised to force you to correct
         your schema.
+
+        Parameters
+        ----------
+        df : pd.DataFrame
+            Target dataframe
+
+        Returns
+        -------
+        pd.DataFrame
         """
         missing = [col for col in self.inputs() if col not in df.columns]
         if len(missing) > 0:
@@ -245,8 +408,19 @@ class Schema(dict):
 
     def select_outputs(self, df: DataFrame) -> DataFrame:
         """
-        Renames var columns to their output names, and selects them.
-        If any columns are missing, an error is raised to remind you to create them.
+        Renames the current columns to output names, and selects them in
+        the order of the schema.
+        If a column isn't found, an error is raised to force you to correct
+        your schema.
+
+        Parameters
+        ----------
+        df : pd.DataFrame
+            Target dataframe
+
+        Returns
+        -------
+        pd.DataFrame
         """
         missing = [col for col in self.keys() if col not in df.columns]
         if len(missing) > 0:
@@ -256,8 +430,12 @@ class Schema(dict):
 
     def reset_inputs(self) -> Schema:
         """
-        Sets all inputs with output values. Use this if you're
-        using a previous schema to read in data that was outputted from it
+        Replaces all input values with the current output values.
+        Use this if you're using a previous schema to read in data that was outputted from it
+
+        Returns
+        -------
+        :class:`Self`
         """
         new = self.copy()
         for key in new.keys():
@@ -266,7 +444,11 @@ class Schema(dict):
 
     def reset_outputs(self) -> Schema:
         """
-        Fills all outputs with the current inputs
+        Replaces all output values with current input values.
+
+        Returns
+        -------
+        :class:`Self`
         """
         new = self.copy()
         for key in new.keys():
